U-Boot Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Sheep Sun <sunxiaoyang2003@gmail.com>
To: u-boot@lists.denx.de
Cc: Sheep Sun <sunxiaoyang2003@gmail.com>,
	Mateusz Kulikowski <mateusz.kulikowski@gmail.com>,
	Ramon Fried <rfried.dev@gmail.com>, Tom Rini <trini@konsulko.com>
Subject: [PATCH 2/2] arm: snapdragon: Fix typo in clk_bcr_update()
Date: Sun, 20 Jun 2021 10:34:35 +0800	[thread overview]
Message-ID: <20210620023435.837965-2-sunxiaoyang2003@gmail.com> (raw)
In-Reply-To: <20210620023435.837965-1-sunxiaoyang2003@gmail.com>

Fix typo in clock-snapdragon.c

Signed-off-by: Sheep Sun <sunxiaoyang2003@gmail.com>
---

 arch/arm/mach-snapdragon/clock-snapdragon.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/arch/arm/mach-snapdragon/clock-snapdragon.c b/arch/arm/mach-snapdragon/clock-snapdragon.c
index fbe0b5212f..2b76371718 100644
--- a/arch/arm/mach-snapdragon/clock-snapdragon.c
+++ b/arch/arm/mach-snapdragon/clock-snapdragon.c
@@ -56,15 +56,15 @@ void clk_enable_vote_clk(phys_addr_t base, const struct vote_clk *vclk)
 	} while ((val != BRANCH_ON_VAL) && (val != BRANCH_NOC_FSM_ON_VAL));
 }
 
-#define APPS_CMD_RGCR_UPDATE BIT(0)
+#define APPS_CMD_RCGR_UPDATE BIT(0)
 
-/* Update clock command via CMD_RGCR */
-void clk_bcr_update(phys_addr_t apps_cmd_rgcr)
+/* Update clock command via CMD_RCGR */
+void clk_bcr_update(phys_addr_t apps_cmd_rcgr)
 {
-	setbits_le32(apps_cmd_rgcr, APPS_CMD_RGCR_UPDATE);
+	setbits_le32(apps_cmd_rcgr, APPS_CMD_RCGR_UPDATE);
 
 	/* Wait for frequency to be updated. */
-	while (readl(apps_cmd_rgcr) & APPS_CMD_RGCR_UPDATE)
+	while (readl(apps_cmd_rcgr) & APPS_CMD_RCGR_UPDATE)
 		;
 }
 
-- 
2.30.2


  reply	other threads:[~2021-06-20  2:35 UTC|newest]

Thread overview: 4+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-06-20  2:34 [PATCH 1/2] arm: snapdragon: Use correct GICC register on APQ8016 Sheep Sun
2021-06-20  2:34 ` Sheep Sun [this message]
2021-07-06 22:50   ` [PATCH 2/2] arm: snapdragon: Fix typo in clk_bcr_update() Tom Rini
2021-07-06 22:50 ` [PATCH 1/2] arm: snapdragon: Use correct GICC register on APQ8016 Tom Rini

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20210620023435.837965-2-sunxiaoyang2003@gmail.com \
    --to=sunxiaoyang2003@gmail.com \
    --cc=mateusz.kulikowski@gmail.com \
    --cc=rfried.dev@gmail.com \
    --cc=trini@konsulko.com \
    --cc=u-boot@lists.denx.de \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox